Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(453)

Unified Diff: third_party/WebKit/Source/platform/PlatformEvent.h

Issue 2233543002: Make first TouchStart and first TouchMove events on a flinging layer non-blocking (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fling intervetion Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/PlatformEvent.h
diff --git a/third_party/WebKit/Source/platform/PlatformEvent.h b/third_party/WebKit/Source/platform/PlatformEvent.h
index ad3883f44d3bc25ab7e9944867b6440936b58dc7..8d5cffd232cfd95058c943323e496539e5f09661 100644
--- a/third_party/WebKit/Source/platform/PlatformEvent.h
+++ b/third_party/WebKit/Source/platform/PlatformEvent.h
@@ -130,8 +130,8 @@ public:
// All listeners are passive.
ListenersNonBlockingPassive,
// This value represents a state which would have normally blocking
- // but was forced to be non-blocking.
- ListenersForcedNonBlockingPassive,
+ // but was forced to be non-blocking during fling; not cancelable.
+ ListenersForcedNonBlockingPassiveDueToFling,
tdresser 2016/08/17 14:32:28 Are we considering these passive, or non-cancellab
lanwei 2016/08/18 12:31:47 I think they are passive and also non-cancellable.
tdresser 2016/08/18 12:43:53 I think I'd prefer if the word "Passive" only refe
};
EventType type() const { return static_cast<EventType>(m_type); }

Powered by Google App Engine
This is Rietveld 408576698